@@ -16,8 +16,9 @@ stests = [
     r'$\mathscr{Script}$']
 
 if sys.maxunicode > 0xffff:
+    s = r'Direct Unicode: $\u23ce \mathrm{\ue0f2 \U0001D538}$'
     stests.append(
-        ur'Direct Unicode: $\u23ce \mathrm{\ue0f2 \U0001D538}$'
+        unicode(s, encoding="unicode_escape")
     )
 
 from pylab import *
@@ -31,7 +32,7 @@ def doall():
     axis([0, 3, -len(tests), 0])
     yticks(arange(len(tests)) * -1)
     for i, s in enumerate(tests):
-        print (i, s.encode("ascii", "backslashreplace"))
+        #print (i, s.encode("ascii", "backslashreplace"))
         text(0.1, -i, s, fontsize=32)
 
     savefig('stix_fonts_example')
