@@ -99,7 +99,8 @@ to MATLAB&reg;, a registered trademark of The MathWorks, Inc.
 """
 from __future__ import generators
 
-__version__  = '1.1.0'
+__version__  = '1.1.1'
+__version__numpy__ = '1.4' # minimum required numpy version
 
 import os, re, shutil, subprocess, sys, warnings
 import distutils.sysconfig
@@ -150,11 +151,17 @@ _havedate = True
 if not _python24:
     raise ImportError('matplotlib requires Python 2.4 or later')
 
+
 import numpy
-nmajor, nminor = [int(n) for n in numpy.__version__.split('.')[:2]]
-if not (nmajor > 1 or (nmajor == 1 and nminor >= 1)):
+from distutils import version
+expected_version = version.LooseVersion(__version__numpy__)
+found_version = version.LooseVersion(numpy.__version__)
+if not found_version >= expected_version:
     raise ImportError(
-            'numpy 1.1 or later is required; you have %s' % numpy.__version__)
+        'numpy %s or later is required; you have %s' % (
+            __version__numpy__, numpy.__version__))
+del version
+
 
 def is_string_like(obj):
     if hasattr(obj, 'shape'): return 0
@@ -895,14 +902,20 @@ def use(arg, warn=True):
 
     will specify a default of pdf output generated by Cairo.
 
-    Note: this function must be called *before* importing pylab for
-    the first time; or, if you are not using pylab, it must be called
-    before importing matplotlib.backends.  If warn is True, a warning
-    is issued if you try and callthis after pylab or pyplot have been
-    loaded.  In certain black magic use cases, eg
-    pyplot.switch_backends, we are doing the reloading necessary to
-    make the backend switch work (in some cases, eg pure image
-    backends) so one can set warn=False to supporess the warnings
+    .. note::
+
+        This function must be called *before* importing pyplot for
+        the first time; or, if you are not using pyplot, it must be called
+        before importing matplotlib.backends.  If warn is True, a warning
+        is issued if you try and call this after pylab or pyplot have been
+        loaded.  In certain black magic use cases, e.g.
+        :func:`pyplot.switch_backends`, we are doing the reloading necessary to
+        make the backend switch work (in some cases, e.g. pure image
+        backends) so one can set warn=False to supporess the warnings.
+
+    To find out which backend is currently set, see
+    :func:`matplotlib.get_backend`.
+
     """
     if 'matplotlib.backends' in sys.modules:
         if warn: warnings.warn(_use_error_msg)
@@ -922,7 +935,7 @@ def use(arg, warn=True):
     rcParams['backend'] = name
 
 def get_backend():
-    "Returns the current backend"
+    "Returns the current backend."
     return rcParams['backend']
 
 def interactive(b):
@@ -974,27 +987,35 @@ default_test_modules = [
     'matplotlib.tests.test_simplification',
     'matplotlib.tests.test_mathtext',
     'matplotlib.tests.test_text',
-    'matplotlib.tests.test_tightlayout'
+    'matplotlib.tests.test_tightlayout',
+    'matplotlib.tests.test_delaunay',
+    'matplotlib.tests.test_legend'
     ]
 
-def test(verbosity=0):
+def test(verbosity=1):
     """run the matplotlib test suite"""
-    import nose
-    import nose.plugins.builtin
-    from testing.noseclasses import KnownFailure
-    from nose.plugins.manager import PluginManager
+    old_backend = rcParams['backend']
+    try:
+        use('agg')
+        import nose
+        import nose.plugins.builtin
+        from testing.noseclasses import KnownFailure
+        from nose.plugins.manager import PluginManager
 
-    # store the old values before overriding
-    plugins = []
-    plugins.append( KnownFailure() )
-    plugins.extend( [plugin() for plugin in nose.plugins.builtin.plugins] )
+        # store the old values before overriding
+        plugins = []
+        plugins.append( KnownFailure() )
+        plugins.extend( [plugin() for plugin in nose.plugins.builtin.plugins] )
 
-    manager = PluginManager(plugins=plugins)
-    config = nose.config.Config(verbosity=verbosity, plugins=manager)
+        manager = PluginManager(plugins=plugins)
+        config = nose.config.Config(verbosity=verbosity, plugins=manager)
 
-    success = nose.run( defaultTest=default_test_modules,
-                        config=config,
-                        )
+        success = nose.run( defaultTest=default_test_modules,
+                            config=config,
+                            )
+    finally:
+        if old_backend.lower() != 'agg':
+            use(old_backend)
 
     return success
 
