@@ -37,12 +37,14 @@ if _DEBUG < 5:
 _DEBUG_lvls = {1 : 'Low ', 2 : 'Med ', 3 : 'High', 4 : 'Error' }
 
 missingwx = "Matplotlib backend_wx and backend_wxagg require wxPython >=2.8"
+missingwxversion = ("Matplotlib backend_wx and backend_wxagg "
+                    "require wxversion, which was not found.")
 
 if not hasattr(sys, 'frozen'): # i.e., not py2exe
     try:
         import wxversion
     except ImportError:
-        raise ImportError(missingwx)
+        raise ImportError(missingwxversion)
 
     # Some early versions of wxversion lack AlreadyImportedError.
     # It was added around 2.8.4?
@@ -1473,6 +1475,8 @@ class FigureFrameWx(wx.Frame):
         self.SetSizer(self.sizer)
         self.Fit()
 
+        self.canvas.SetMinSize((2, 2))
+
         self.figmgr = FigureManagerWx(self.canvas, num, self)
 
         bind(self, wx.EVT_CLOSE, self._onClose)
