@@ -27,6 +27,7 @@ from matplotlib._image import *
 from matplotlib.transforms import BboxBase, Bbox
 import matplotlib.transforms as mtransforms
 
+
 class _AxesImageBase(martist.Artist, cm.ScalarMappable):
     zorder = 0
     # map interpolation strings to module constants
@@ -69,7 +70,6 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
                  resample = False,
                  **kwargs
                  ):
-
         """
         interpolation and cmap default to their rc settings
 
@@ -100,14 +100,14 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
 
         # this is an experimental attribute, if True, unsampled image
         # will be drawn using the affine transform that are
-        # appropriately skewed so that the given postition
+        # appropriately skewed so that the given position
         # corresponds to the actual position in the coordinate. -JJL
         self._image_skew_coordinate = None
 
         self.update(kwargs)
 
     def get_size(self):
-        'Get the numrows, numcols of the input image'
+        """Get the numrows, numcols of the input image"""
         if self._A is None:
             raise RuntimeError('You must first set the image array')
 
@@ -135,7 +135,6 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
     def make_image(self, magnification=1.0):
         raise RuntimeError('The make_image method must be overridden.')
 
-
     def _get_unsampled_image(self, A, image_extents, viewlim):
         """
         convert numpy array A with given extents ([x1, x2, y1, y2] in
@@ -199,7 +198,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
                 im.is_grayscale = False
             else:
                 if self._rgbacache is None:
-                    x = self.to_rgba(self._A, self._alpha, bytes=True)
+                    x = self.to_rgba(self._A, bytes=True)
                     self._rgbacache = x
                 else:
                     x = self._rgbacache
@@ -217,7 +216,6 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
 
         return im, xmin, ymin, dxintv, dyintv, sx, sy
 
-
     @staticmethod
     def _get_rotate_and_skew_transform(x1, y1, x2, y2, x3, y3):
         """
@@ -247,19 +245,16 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
 
         return tr
 
-
     def _draw_unsampled_image(self, renderer, gc):
         """
         draw unsampled image. The renderer should support a draw_image method
         with scale parameter.
         """
-
-
         trans = self.get_transform() #axes.transData
 
         # convert the coordinates to the intermediate coordinate (ic).
         # The transformation from the ic to the canvas is a pure
-        # affine transfor.
+        # affine transform.
 
         # A straight-forward way is to use the non-affine part of the
         # original transform for conversion to the ic.
@@ -290,7 +285,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
         else:
             trans_ic_to_canvas = trans.get_affine()
 
-        # Now, viewLim in the ic.  It can be roated and can be
+        # Now, viewLim in the ic.  It can be rotated and can be
         # skewed. Make it big enough.
         x1, y1, x2, y2 = self.axes.bbox.extents
         trans_canvas_to_ic = trans_ic_to_canvas.inverted()
@@ -326,7 +321,6 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
         renderer.draw_image(gc, xmin, ymin, im, dxintv, dyintv,
                             trans_ic_to_canvas)
 
-
     def _check_unsampled_image(self, renderer):
         """
         return True if the image is better to be drawn unsampled.
@@ -345,6 +339,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
         gc = renderer.new_gc()
         gc.set_clip_rectangle(self.axes.bbox.frozen())
         gc.set_clip_path(self.get_clip_path())
+        gc.set_alpha(self.get_alpha())
 
         if self._check_unsampled_image(renderer):
             self._draw_unsampled_image(renderer, gc)
@@ -422,7 +417,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
 
     def set_array(self, A):
         """
-        retained for backwards compatibility - use set_data instead
+        Retained for backwards compatibility - use set_data instead
 
         ACCEPTS: numpy array A or PIL Image"""
         # This also needs to be here to override the inherited
@@ -431,8 +426,6 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
 
         self.set_data(A)
 
-
-
     def get_interpolation(self):
         """
         Return the interpolation method the image uses when resizing.
@@ -440,6 +433,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
         One of 'nearest', 'bilinear', 'bicubic', 'spline16', 'spline36', 'hanning',
         'hamming', 'hermite', 'kaiser', 'quadric', 'catrom', 'gaussian',
         'bessel', 'mitchell', 'sinc', 'lanczos', or 'none'.
+
         """
         return self._interpolation
 
@@ -466,7 +460,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
 
     def set_resample(self, v):
         """
-        set whether or not image resampling is used
+        Set whether or not image resampling is used
 
         ACCEPTS: True|False
         """
@@ -474,7 +468,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
         self._resample = v
 
     def get_resample(self):
-        'return the image resample boolean'
+        """Return the image resample boolean"""
         return self._resample
 
     def set_filternorm(self, filternorm):
@@ -490,7 +484,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
             self._filternorm = 0
 
     def get_filternorm(self):
-        'return the filternorm setting'
+        """Return the filternorm setting"""
         return self._filternorm
 
     def set_filterrad(self, filterrad):
@@ -505,7 +499,7 @@ class _AxesImageBase(martist.Artist, cm.ScalarMappable):
         self._filterrad = r
 
     def get_filterrad(self):
-        'return the filterrad setting'
+        """return the filterrad setting"""
         return self._filterrad
 
 
@@ -645,7 +639,7 @@ class AxesImage(_AxesImageBase):
             self.axes.set_ylim((ymin, ymax), auto=None)
 
     def get_extent(self):
-        'get the image extent: left, right, bottom, top'
+        """Get the image extent: left, right, bottom, top"""
         if self._extent is not None:
             return self._extent
         else:
@@ -722,7 +716,7 @@ class NonUniformImage(AxesImage):
             A.shape = A.shape[0:2]
         if len(A.shape) == 2:
             if A.dtype != np.uint8:
-                A = self.to_rgba(A, alpha=self._alpha, bytes=True)
+                A = self.to_rgba(A, bytes=True)
                 self.is_grayscale = self.cmap.is_gray()
             else:
                 A = np.repeat(A[:,:,np.newaxis], 4, 2)
@@ -779,12 +773,12 @@ class NonUniformImage(AxesImage):
         cm.ScalarMappable.set_cmap(self, cmap)
 
 class PcolorImage(martist.Artist, cm.ScalarMappable):
-    '''
+    """
     Make a pcolor-style plot with an irregular rectangular grid.
 
     This uses a variation of the original irregular image code,
     and it is used by pcolorfast for the corresponding grid type.
-    '''
+    """
     def __init__(self, ax,
                  x=None,
                  y=None,
@@ -824,7 +818,7 @@ class PcolorImage(martist.Artist, cm.ScalarMappable):
         width = width * magnification
         height = height * magnification
         if self._rgbacache is None:
-            A = self.to_rgba(self._A, alpha=self._alpha, bytes=True)
+            A = self.to_rgba(self._A, bytes=True)
             self._rgbacache = A
             if self._A.ndim == 2:
                 self.is_grayscale = self.cmap.is_gray()
@@ -851,6 +845,7 @@ class PcolorImage(martist.Artist, cm.ScalarMappable):
         gc = renderer.new_gc()
         gc.set_clip_rectangle(self.axes.bbox.frozen())
         gc.set_clip_path(self.get_clip_path())
+        gc.set_alpha(self.get_alpha())
         renderer.draw_image(gc,
                             round(self.axes.bbox.xmin),
                             round(self.axes.bbox.ymin),
@@ -931,8 +926,7 @@ class FigureImage(martist.Artist, cm.ScalarMappable):
         self.magnification = 1.0
 
     def contains(self, mouseevent):
-        """Test whether the mouse event occured within the image.
-        """
+        """Test whether the mouse event occured within the image."""
         if callable(self._contains): return self._contains(self,mouseevent)
         xmin, xmax, ymin, ymax = self.get_extent()
         xdata, ydata = mouseevent.x, mouseevent.y
@@ -945,36 +939,31 @@ class FigureImage(martist.Artist, cm.ScalarMappable):
         return inside,{}
 
     def get_size(self):
-        'Get the numrows, numcols of the input image'
+        """Get the numrows, numcols of the input image"""
         if self._A is None:
             raise RuntimeError('You must first set the image array')
 
         return self._A.shape[:2]
 
     def get_extent(self):
-        'get the image extent: left, right, bottom, top'
+        """Get the image extent: left, right, bottom, top"""
         numrows, numcols = self.get_size()
         return (-0.5+self.ox, numcols-0.5+self.ox,
                 -0.5+self.oy, numrows-0.5+self.oy)
 
     def set_data(self, A):
-        """
-        Set the image array
-
-        """
+        """Set the image array."""
         cm.ScalarMappable.set_array(self, cbook.safe_masked_invalid(A))
 
     def set_array(self, A):
-        """
-        Deprecated; use set_data for consistency with other image types.
-        """
+        """Deprecated; use set_data for consistency with other image types."""
         self.set_data(A)
 
     def make_image(self, magnification=1.0):
         if self._A is None:
             raise RuntimeError('You must first set the image array')
 
-        x = self.to_rgba(self._A, self._alpha, bytes=True)
+        x = self.to_rgba(self._A, bytes=True)
         self.magnification = magnification
         # if magnification is not one, we need to resize
         ismag = magnification!=1
@@ -1008,6 +997,7 @@ class FigureImage(martist.Artist, cm.ScalarMappable):
         gc = renderer.new_gc()
         gc.set_clip_rectangle(self.figure.bbox)
         gc.set_clip_path(self.get_clip_path())
+        gc.set_alpha(self.get_alpha())
         renderer.draw_image(gc, round(self.ox), round(self.oy), im)
         gc.restore()
 
@@ -1019,9 +1009,7 @@ class FigureImage(martist.Artist, cm.ScalarMappable):
 
 
 class BboxImage(_AxesImageBase):
-    """
-    The Image class whose size is determined by the given bbox.
-    """
+    """The Image class whose size is determined by the given bbox."""
     def __init__(self, bbox,
                  cmap = None,
                  norm = None,
@@ -1038,8 +1026,8 @@ class BboxImage(_AxesImageBase):
         norm is a colors.Normalize instance to map luminance to 0-1
 
         kwargs are an optional list of Artist keyword args
-        """
 
+        """
         _AxesImageBase.__init__(self, ax=None,
                                 cmap = cmap,
                                 norm = norm,
@@ -1066,9 +1054,7 @@ class BboxImage(_AxesImageBase):
 
 
     def contains(self, mouseevent):
-        """Test whether the mouse event occured within the image.
-        """
-
+        """Test whether the mouse event occured within the image."""
         if callable(self._contains): return self._contains(self,mouseevent)
 
         if not self.get_visible():# or self.get_figure()._renderer is None:
@@ -1080,7 +1066,7 @@ class BboxImage(_AxesImageBase):
         return inside,{}
 
     def get_size(self):
-        'Get the numrows, numcols of the input image'
+        """Get the numrows, numcols of the input image"""
         if self._A is None:
             raise RuntimeError('You must first set the image array')
 
@@ -1096,7 +1082,7 @@ class BboxImage(_AxesImageBase):
                 im.is_grayscale = False
             else:
                 if self._rgbacache is None:
-                    x = self.to_rgba(self._A, self._alpha, bytes=True)
+                    x = self.to_rgba(self._A, bytes=True)
                     self._rgbacache = x
                 else:
                     x = self._rgbacache
@@ -1138,7 +1124,6 @@ class BboxImage(_AxesImageBase):
                   norm=self._filternorm, radius=self._filterrad)
         return im
 
-
     @allow_rasterization
     def draw(self, renderer, *args, **kwargs):
         if not self.get_visible(): return
@@ -1148,12 +1133,12 @@ class BboxImage(_AxesImageBase):
         l, b, r, t = self.get_window_extent(renderer).extents
         gc = renderer.new_gc()
         self._set_gc_clip(gc)
+        gc.set_alpha(self.get_alpha())
         #gc.set_clip_path(self.get_clip_path())
         renderer.draw_image(gc, round(l), round(b), im)
         gc.restore()
 
 
-
 def imread(fname, format=None):
     """
     Return image file in *fname* as :class:`numpy.array`.  *fname* may
@@ -1174,7 +1159,7 @@ def imread(fname, format=None):
     """
 
     def pilread():
-        'try to load the image with PIL or return None'
+        """try to load the image with PIL or return None"""
         try: from PIL import Image
         except ImportError: return None
         image = Image.open( fname )
@@ -1256,7 +1241,7 @@ def pil_to_array( pilImage ):
     return value is MxNx3.  For RGBA images the return value is MxNx4
     """
     def toarray(im):
-        'return a 1D array of floats'
+        """Teturn a 1D array of floats."""
         x_str = im.tostring('raw',im.mode,0,-1)
         x = np.fromstring(x_str,np.uint8)
         return x
@@ -1287,6 +1272,7 @@ def pil_to_array( pilImage ):
     x.shape = im.size[1], im.size[0], 4
     return x
 
+
 def thumbnail(infile, thumbfile, scale=0.1, interpolation='bilinear',
               preview=False):
     """
@@ -1324,7 +1310,6 @@ def thumbnail(infile, thumbfile, scale=0.1, interpolation='bilinear',
     Return value is the figure instance containing the thumbnail
 
     """
-
     basedir, basename = os.path.split(infile)
     baseout, extout = os.path.splitext(thumbfile)
 
@@ -1335,7 +1320,6 @@ def thumbnail(infile, thumbfile, scale=0.1, interpolation='bilinear',
     # need it for the mpl API
     dpi = 100
 
-
     height = float(rows)/dpi*scale
     width = float(cols)/dpi*scale
 
