@@ -208,7 +208,7 @@ class Formatter(TickHelper):
         Note, if you use this method, eg in :meth`format_data` or
         call, you probably don't want to use it for
         :meth:`format_data_short` since the toolbar uses this for
-        interative coord reporting and I doubt we can expect GUIs
+        interactive coord reporting and I doubt we can expect GUIs
         across platforms will handle the unicode correctly.  So for
         now the classes that override :meth:`fix_minus` should have an
         explicit :meth:`format_data_short` method
@@ -523,7 +523,7 @@ class ScalarFormatter(Formatter):
         # transform 1e+004 into 1e4, for example
         if self._useLocale:
             decimal_point = locale.localeconv()['decimal_point']
-            positive = locale.localeconv()['positive_sign']
+            positive_sign = locale.localeconv()['positive_sign']
         else:
             decimal_point = '.'
             positive_sign = '+'
@@ -545,7 +545,7 @@ class ScalarFormatter(Formatter):
             else:
                 s = ('%se%s%s' %(significand, sign, exponent)).rstrip('e')
                 return s
-        except IndexError, msg:
+        except IndexError:
             return s
 
 
@@ -809,8 +809,10 @@ class Locator(TickHelper):
     def raise_if_exceeds(self, locs):
         'raise a RuntimeError if Locator attempts to create more than MAXTICKS locs'
         if len(locs)>=self.MAXTICKS:
-           raise RuntimeError('Locator attempting to generate %d ticks from %s to %s: exceeds Locator.MAXTICKS'%(len(locs), locs[0], locs[-1]))
-
+            msg = ('Locator attempting to generate %d ticks from %s to %s: ' +
+                   'exceeds Locator.MAXTICKS') % (len(locs), locs[0], locs[-1]) 
+            raise RuntimeError(msg) 
+                                
         return locs
 
     def view_limits(self, vmin, vmax):
@@ -1525,15 +1527,22 @@ class AutoMinorLocator(Locator):
         try:
             majorstep = majorlocs[1] - majorlocs[0]
         except IndexError:
-            raise ValueError('Need at least two major ticks to find minor '
-                             'tick locations')
+            # Need at least two major ticks to find minor tick locations
+            # TODO: Figure out a way to still be able to display minor
+            # ticks without two major ticks visible. For now, just display
+            # no ticks at all.
+            majorstep = 0
 
         if self.ndivs is None:
-            x = int(round(10 ** (np.log10(majorstep) % 1)))
-            if x in [1, 5, 10]:
-                ndivs = 5
-            else:
-                ndivs = 4
+            if majorstep == 0 :
+                # TODO: Need a better way to figure out ndivs
+                ndivs = 1
+            else :
+                x = int(round(10 ** (np.log10(majorstep) % 1)))
+                if x in [1, 5, 10]:
+                    ndivs = 5
+                else:
+                    ndivs = 4
         else:
             ndivs = self.ndivs
 
@@ -1543,12 +1552,15 @@ class AutoMinorLocator(Locator):
         if vmin > vmax:
             vmin,vmax = vmax,vmin
 
-        t0 = majorlocs[0]
-        tmin = np.ceil((vmin - t0) / minorstep) * minorstep
-        tmax = np.floor((vmax - t0) / minorstep) * minorstep
-        locs = np.arange(tmin, tmax, minorstep) + t0
-        cond = np.abs((locs - t0) % majorstep) > minorstep/10.0
-        locs = locs.compress(cond)
+        if len(majorlocs) > 0:
+            t0 = majorlocs[0]
+            tmin = np.ceil((vmin - t0) / minorstep) * minorstep
+            tmax = np.floor((vmax - t0) / minorstep) * minorstep
+            locs = np.arange(tmin, tmax, minorstep) + t0
+            cond = np.abs((locs - t0) % majorstep) > minorstep/10.0
+            locs = locs.compress(cond)
+        else:
+            locs = []
 
         return self.raise_if_exceeds(np.array(locs))
 
