@@ -10,7 +10,7 @@ axis_artist.py module provides axis-related artists. They are
 The main artist class is a AxisArtist and a GridlinesCollection. The
 GridlinesCollection is responsible for drawing grid lines and the
 AxisArtist is responsible for all other artists. The AxisArtist class
-has attributest that are associated with each type of artists.
+has attributes that are associated with each type of artists.
 
  * line : axis line
  * major_ticks : major tick lines
@@ -25,11 +25,14 @@ axis is
 
   ax.axis["bottom"]
 
-where *ax* is an instance of axes (mpl_toolkits.axislines.Axes).
-Thus, ax.axis["bottom"].line is an artist associated with the axis line, and ax.axis["bottom"].major_ticks is an artist associated with the major tick lines.
+where *ax* is an instance of axes (mpl_toolkits.axislines.Axes).  Thus,
+ax.axis["bottom"].line is an artist associated with the axis line, and
+ax.axis["bottom"].major_ticks is an artist associated with the major tick
+lines.
 
 You can change the colors, fonts, line widths, etc. of these artists
-by calling sutable set method. For example, to change the color of the major ticks of the bottom axis to red,
+by calling suitable set method. For example, to change the color of the major
+ticks of the bottom axis to red,
 
   ax.axis["bottom"].major_ticks.set_color("r")
 
@@ -39,7 +42,7 @@ to be changed from the side of the grid_helper.
 axis_direction
 --------------
 
-AxisArtist, AxisLabel, TickLabels have *axis_drection* attribute,
+AxisArtist, AxisLabel, TickLabels have *axis_direction* attribute,
 which adjusts the location, angle, etc.,. The *axis_direction* must be
 one of [left, right, bottom, top] and they follow the matplotlib
 convention for the rectangle axis.
@@ -62,7 +65,7 @@ to the ticklabel), which gives 0 for bottom axis.
  ticklabels angle       90    0      -90  180
  axislabel angle        180   0     0     180
  ticklabel va           center baseline center baseline
- axislabel va           center top      center btoom
+ axislabel va           center top      center bottom
  ticklabel ha           right  center   right  center
  axislabel ha           right  center   right  center
 
@@ -177,7 +180,7 @@ class AttributeCopier(object):
         self._ref_artist = artist
 
     def get_ref_artist(self):
-        raise RuntimeError("get_ref_artist must overriden")
+        raise RuntimeError("get_ref_artist must overridden")
     #return self._ref_artist
 
     def get_attribute_from_ref_artist(self, attr_name, default_value):
@@ -257,7 +260,7 @@ class Ticks(Line2D, AttributeCopier):
 
     def set_ticksize(self, ticksize):
         """
-        set lenth of the ticks in points.
+        set length of the ticks in points.
         """
         self._ticksize = ticksize
 
@@ -448,7 +451,7 @@ class LabelBase(mtext.Text):
         offset_tr.translate(dx, dy)
         self.set_rotation(text_ref_angle+angle_orig)
 
-        bbox = super(LabelBase, self).get_window_extent(renderer)
+        bbox = super(LabelBase, self).get_window_extent(renderer).frozen()
 
         offset_tr.clear()
 
@@ -490,7 +493,7 @@ def test_labelbase():
 class AxisLabel(LabelBase, AttributeCopier):
     """
     Axis Label. Derived from Text. The position of the text is updated
-    in the fly, so chaning text position has no effect. Otherwise, the
+    in the fly, so changing text position has no effect. Otherwise, the
     properties can be changed as a normal Text.
 
     To change the pad between ticklabels and axis label, use set_pad.
@@ -587,7 +590,7 @@ class AxisLabel(LabelBase, AttributeCopier):
         property                 left       bottom    right      top
         =====================    ========== ========= ========== ==========
         axislabel angle          180        0         0          180
-        axislabel va             center     top       center     btoom
+        axislabel va             center     top       center     bottom
         axislabel ha             right      center    right      center
         =====================    ========== ========= ========== ==========
 
@@ -616,6 +619,20 @@ class AxisLabel(LabelBase, AttributeCopier):
         super(AxisLabel, self).draw(renderer)
 
 
+    def get_window_extent(self, renderer):
+
+        if not self.get_visible():
+            return
+
+        pad = renderer.points_to_pixels(self.get_pad())
+        r = self._get_external_pad() + pad
+        self._set_offset_radius(r)
+
+        bb = super(AxisLabel, self).get_window_extent(renderer)
+
+        return bb
+
+
 class TickLabels(AxisLabel, AttributeCopier): # mtext.Text
     """
     Tick Labels. While derived from Text, this single artist draws all
@@ -759,7 +776,7 @@ class TickLabels(AxisLabel, AttributeCopier): # mtext.Text
             return
 
         r, total_width = self._get_ticklabels_offsets(renderer,
-                                                     self._axis_direction)
+                                                      self._axis_direction)
 
         #self._set_external_pad(r+self._get_external_pad())
         pad = self._get_external_pad() + \
@@ -785,6 +802,10 @@ class TickLabels(AxisLabel, AttributeCopier): # mtext.Text
 
     def get_window_extents(self, renderer):
 
+        if not self.get_visible():
+            self._axislabel_pad = self._get_external_pad()
+            return []
+
         bboxes = []
 
         r, total_width = self._get_ticklabels_offsets(renderer,
@@ -803,12 +824,15 @@ class TickLabels(AxisLabel, AttributeCopier): # mtext.Text
             bb = LabelBase.get_window_extent(self, renderer)
             bboxes.append(bb)
 
+        self._axislabel_pad = total_width \
+                              + pad # the value saved will be used to draw axislabel.
+
         return bboxes
 
 
     def get_texts_widths_heights_descents(self, renderer):
         """
-        return a list of width, height, descent for ticklaels.
+        return a list of width, height, descent for ticklabels.
         """
         whd_list = []
         for (x, y), a, l in self._locs_angles_labels:
@@ -981,7 +1005,7 @@ class AxisArtist(martist.Artist):
         ticklabel va             center     baseline  center     baseline
         ticklabel ha             right      center    right      center
         axislabel angle          180        0         0          180
-        axislabel va             center     top       center     btoom
+        axislabel va             center     top       center     bottom
         axislabel ha             right      center    right      center
         =====================    ========== ========= ========== ==========
 
@@ -1207,8 +1231,69 @@ class AxisArtist(martist.Artist):
         return ticks_loc_angle, ticklabels_loc_angle_label
 
 
+    def _update_ticks(self, renderer):
+
+
+        # set extra pad for major and minor ticklabels:
+        # use ticksize of majorticks even for minor ticks. not clear what is best.
+
+        dpi_cor = renderer.points_to_pixels(1.)
+        if self.major_ticks.get_visible() and self.major_ticks.get_tick_out():
+            self.major_ticklabels._set_external_pad(self.major_ticks._ticksize*dpi_cor)
+            self.minor_ticklabels._set_external_pad(self.major_ticks._ticksize*dpi_cor)
+        else:
+            self.major_ticklabels._set_external_pad(0)
+            self.minor_ticklabels._set_external_pad(0)
+
+
+        majortick_iter,  minortick_iter = \
+                self._axis_artist_helper.get_tick_iterators(self.axes)
+
+        tick_loc_angle, ticklabel_loc_angle_label \
+                              = self._get_tick_info(majortick_iter)
+
+        self.major_ticks.set_locs_angles(tick_loc_angle)
+        self.major_ticklabels.set_locs_angles_labels(ticklabel_loc_angle_label)
+
+        #self.major_ticks.draw(renderer)
+        #self.major_ticklabels.draw(renderer)
+
+
+        # minor ticks
+        tick_loc_angle, ticklabel_loc_angle_label \
+                              = self._get_tick_info(minortick_iter)
+
+        self.minor_ticks.set_locs_angles(tick_loc_angle)
+        self.minor_ticklabels.set_locs_angles_labels(ticklabel_loc_angle_label)
+
+        #self.minor_ticks.draw(renderer)
+        #self.minor_ticklabels.draw(renderer)
+
+
+        #if (self.major_ticklabels.get_visible() or self.minor_ticklabels.get_visible()):
+        #    self._draw_offsetText(renderer)
+
+        return self.major_ticklabels.get_window_extents(renderer)
+
+
     def _draw_ticks(self, renderer):
 
+        extents = self._update_ticks(renderer)
+
+        self.major_ticks.draw(renderer)
+        self.major_ticklabels.draw(renderer)
+
+        self.minor_ticks.draw(renderer)
+        self.minor_ticklabels.draw(renderer)
+
+
+        if (self.major_ticklabels.get_visible() or self.minor_ticklabels.get_visible()):
+            self._draw_offsetText(renderer)
+
+        return extents
+
+    def _draw_ticks2(self, renderer):
+
 
         # set extra pad for major and minor ticklabels:
         # use ticksize of majorticks even for minor ticks. not clear what is best.
@@ -1296,7 +1381,9 @@ class AxisArtist(martist.Artist):
                            rcParams['axes.labelsize'])
         #labelcolor = kw.get("labelcolor",
         #                    rcParams['axes.labelcolor'])
-        fontprops = font_manager.FontProperties(size=labelsize)
+        fontprops = font_manager.FontProperties(
+            size=labelsize,
+            weight=rcParams['axes.labelweight'])
         textprops = dict(fontproperties = fontprops)
                          #color = labelcolor)
 
@@ -1316,12 +1403,60 @@ class AxisArtist(martist.Artist):
         labelpad = kw.get("labelpad", 5)
         self.label.set_pad(labelpad)
 
-    def _draw_label(self, renderer):
+
+    def _update_label(self, renderer):
 
         if not self.label.get_visible():
             return
 
-        fontprops = font_manager.FontProperties(size=rcParams['axes.labelsize'])
+        fontprops = font_manager.FontProperties(
+            size=rcParams['axes.labelsize'],
+            weight=rcParams['axes.labelweight'])
+
+        #pad_points = self.major_tick_pad
+
+        #print self._ticklabel_add_angle - self._axislabel_add_angle
+        #if abs(self._ticklabel_add_angle - self._axislabel_add_angle)%360 > 90:
+        if self._ticklabel_add_angle !=  self._axislabel_add_angle:
+            if (self.major_ticks.get_visible() and not self.major_ticks.get_tick_out()) \
+               or \
+               (self.minor_ticks.get_visible() and not self.major_ticks.get_tick_out()):
+                axislabel_pad = self.major_ticks._ticksize
+            else:
+                axislabel_pad = 0
+        else:
+            axislabel_pad = max([self.major_ticklabels._axislabel_pad,
+                                 self.minor_ticklabels._axislabel_pad])
+
+
+        #label_offset =  axislabel_pad + self.LABELPAD
+
+        #self.label._set_offset_radius(label_offset)
+        self.label._set_external_pad(axislabel_pad)
+
+        xy, angle_tangent = self._axis_artist_helper.get_axislabel_pos_angle(self.axes)
+        if xy is None: return
+
+        angle_label = angle_tangent  - 90
+
+
+        x, y = xy
+        self.label._set_ref_angle(angle_label+self._axislabel_add_angle)
+        self.label.set(x=x, y=y)
+
+
+    def _draw_label(self, renderer):
+        self._update_label(renderer)
+        self.label.draw(renderer)
+
+    def _draw_label2(self, renderer):
+
+        if not self.label.get_visible():
+            return
+
+        fontprops = font_manager.FontProperties(
+            size=rcParams['axes.labelsize'],
+            weight=rcParams['axes.labelweight'])
 
         #pad_points = self.major_tick_pad
 
@@ -1361,6 +1496,48 @@ class AxisArtist(martist.Artist):
         self.label.set_text(s)
 
 
+
+    def get_tightbbox(self, renderer):
+        if not self.get_visible(): return
+
+        self._axis_artist_helper.update_lim(self.axes)
+
+        dpi_cor = renderer.points_to_pixels(1.)
+        self.dpi_transform.clear().scale(dpi_cor, dpi_cor)
+
+
+        bb = []
+
+        self._update_ticks(renderer)
+
+        #if self.major_ticklabels.get_visible():
+        bb.extend(self.major_ticklabels.get_window_extents(renderer))
+        #if self.minor_ticklabels.get_visible():
+        bb.extend(self.minor_ticklabels.get_window_extents(renderer))
+
+
+        self._update_label(renderer)
+
+        #if self.label.get_visible():
+        bb.append(self.label.get_window_extent(renderer))
+        bb.append(self.offsetText.get_window_extent(renderer))
+
+        bb = [b for b in bb if b and (b.width!=0 or b.height!=0)]
+        if bb:
+            _bbox = Bbox.union(bb)
+            return _bbox
+        else:
+            return None
+
+        #self._draw_line(renderer)
+
+        #self._draw_ticks(renderer)
+
+        #self._draw_offsetText(renderer)
+        #self._draw_label(renderer)
+
+
+
     @allow_rasterization
     def draw(self, renderer):
         'Draw the axis lines, tick lines and labels'
@@ -1375,10 +1552,10 @@ class AxisArtist(martist.Artist):
         self.dpi_transform.clear().scale(dpi_cor, dpi_cor)
 
 
-        self._draw_line(renderer)
-
         self._draw_ticks(renderer)
 
+        self._draw_line(renderer)
+
         #self._draw_offsetText(renderer)
         self._draw_label(renderer)
 
